# python-lexode

lexicographic packing and unpacking functions for ordered key-value stores

![Funny bunny in front of brick of wall](https://images.unsplash.com/photo-1584759985030-352927f481a3?ixlib=rb-1.2.1&q=80&fm=jpg&crop=entropy&cs=tinysrgb&w=1080&fit=max&ixid=eyJhcHBfaWQiOjEyMDd9)
